@@ -1,9 +1,8 @@
 from os import chown, unlink
 
+from ecoindex.models import ScreenShot
 from PIL import Image
 
-from ecoindex_scraper.models import ScreenShot
-
 
 def convert_screenshot_to_webp(screenshot: ScreenShot) -> None:
     image = Image.open(rf"{screenshot.get_png()}")
